
/* Generated data (by glib-mkenums) */

#ifndef __LIBGNOMEPRINT_ENUM_TYPES_H__
#define __LIBGNOMEPRINT_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "gnome-print-filter.h" */
GType gnome_print_filter_error_get_type (void);
#define GNOME_TYPE_PRINT_PRINT_FILTER_ERROR (gnome_print_filter_error_get_type())
/* enumerations from "gnome-print.h" */
GType gnome_print_return_code_get_type (void);
#define GNOME_TYPE_PRINT_PRINT_RETURN_CODE (gnome_print_return_code_get_type())
/* enumerations from "gnome-print-unit.h" */
GType gnome_print_unit_base_get_type (void);
#define GNOME_TYPE_PRINT_PRINT_UNIT_BASE (gnome_print_unit_base_get_type())
G_END_DECLS

#endif /* __LIBGNOMEPRINT_ENUM_TYPES_H__ */

/* Generated data ends here */

